0,1,4-fach 10V Dimmer 
19,210,Rote Modul LED
21,49,Dimmer 1
21,50,Dimmer 2
21,51,Dimmer 3
21,52,Dimmer 4
16,17,Eingang 1
16,18,Eingang 2
16,19,Eingang 3
16,20,Eingang 4
36,17,Analogeingang 1
36,18,Analogeingang 2
36,19,Analogeingang 3
36,20,Analogeingang 4
