0,1,2-fach Taster
16,19,Taster 1
16,20,Taster 2
21,51,Led 1
21,52,Led 2
20,16,Hintergrundbeleuchtung
16,33,Extern Taster 1
16,34,Extern Taster 2
16,35,Extern Taster 3
16,36,Extern Taster 4
16,37,Extern Taster 5
16,38,Extern Taster 6
21,65,Extern Led 1
21,66,Extern Led 2
21,67,Extern Led 3
21,68,Extern Led 4
21,69,Extern Led 5
21,70,Extern Led 6
32,1,Temperatursensor
34,1,Feuchtesensor
39,1,Helligkeitssensor
43,65,RFID Leser
43,67,RFID Leser
43,69,RFID Leser
164,1,WiFi