0,1,8-fach Motormodul
19,210,Rote Modul LED
18,1,Motor 1
18,2,Motor 2
18,3,Motor 3
18,4,Motor 4
18,5,Motor 5
18,6,Motor 6
18,7,Motor 7
18,8,Motor 8
16,97,Eingang 1
16,98,Eingang 2
16,99,Eingang 3
16,100,Eingang 4
16,101,Eingang 5
16,102,Eingang 6
16,103,Eingang 7
16,104,Eingang 8