0,1,24-fach UP-IO
19,210,Rote Modul LED
16,17,Eingang 1
16,18,Eingang 2
16,19,Eingang 3
16,20,Eingang 4
16,21,Eingang 5
16,22,Eingang 6
16,33,Eingang 7
16,34,Eingang 8
16,35,Eingang 9
16,36,Eingang 10
16,37,Eingang 11
16,38,Eingang 12
21,49,Ausgang 1
21,50,Ausgang 2
21,51,Ausgang 3
21,52,Ausgang 4
21,53,Ausgang 5
21,54,Ausgang 6
21,65,Ausgang 7
21,66,Ausgang 8
21,67,Ausgang 9
21,68,Ausgang 10
21,69,Ausgang 11
21,70,Ausgang 12
32,1,Temperatursensor 1
32,2,Temperatursensor 2
32,3,Temperatursensor 3
32,4,Temperatursensor 4
32,5,Temperatursensor 5